==> shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17.tar.gz: shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/ui-visualisation/ui_hive/ui_dashboard/shinken-auto-test-run.js <==
SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD_RUN = (function ( self ) {
    var _timeout = 0;
    var _current_window;
    var _current_property;
    var _to_test;
    
    function ____ ( fct ) {
        _timeout += fct;
        return _timeout;
    }
    
    self.do = function () {
        switch ( __shinken_test_type ) {
            case "00227":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout, "/etc/shinken/modules/sla.cfg", "downtime_period", "exclude" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout, "/etc/shinken/modules/sla.cfg", "unknown_period", "exclude" ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.deleteElement( _timeout, OBJECT.ShinkenElementFactory( {
                            "_id"      : '00000000000000000000000000000227',
                            "host_name": '00227_test_auto_host',
                            "type"     : OBJECT.CONST.ELEMENT.TYPE.HOSTS
                        } ) ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                        _timeout += 10000;
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SLA.ACTION.removeTodaySLAFromUUID( _timeout, "00000000000000000000000000000227" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202], false, "00227-1" ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                        _timeout += 4000;
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( _timeout, "shinken", "hive", "hive-0000000000000000000000000227", {
                            "_id"    : "hive-0000000000000000000000000227", "name": "TEST_AUTO 00227 Hive", "owner": { "uuid": "35000000000000000000000000000000" }, "saveVersion": 1, "tiles": [
                                {
                                    "position": { "x": 0, "y": 0 }, "screen": { "uuid": "dash-00000000000000000000000000000227" }
                                }
                            ], "type": "hive", "uuid": "hive-0000000000000000000000000227", "version": "V02.05.01-RC002"
                        } ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( _timeout, "shinken", "dashboard", "dash-00000000000000000000000000000227", {
                            "_id"        : "dash-00000000000000000000000000000227", "context": "NOTHING", "groupId": 0, "has_unknown_element": false, "name": "TEST_AUTO 00227 Dashboard", "parentScreenUuid": "hive-0000000000000000000000000227",
                            "saveVersion": 1, "status": 3,
                            "uuid"       : "dash-00000000000000000000000000000227", "version": "V02.05.01-RC002", "widgets": [
                                {
                                    "display_name": "SLA", "display_sla_full": true,
                                    "element"     : { "host_name": "00227_test_auto_host", "is_unknown": false, "sla": { "growing": "arrow-stagnant-critical", "week_percentage": 0 }, "uuid": "00000000000000000000000000000227" }, "favorite": false,
                                    "height"      : 3, "inCalculation": false, "name": "sla", "position": { "x": 0, "y": 0 }, "uuid": "widget-00000000000000000000000000000227", "width": 4
                                }
                            ]
                        } ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( _timeout, "shinken", "share", "share-0000000000000000000000000227", {
                            "_id"  : "share-0000000000000000000000000227", "index": 1, "kind": 1, "uuid": "share-0000000000000000000000000227", "screen": { "type": "hive", "uuid": "hive-0000000000000000000000000227" }, "created_on": 1649855720,
                            "owner": { "uuid": "35000000000000000000000000000000", "name": "test_auto_user_executor" }, "screenIsReference": false, "type": "personal", "last_modified_on": 1649855720, "name": "TEST_AUTO 00227 Share"
                        } ) );
                        _timeout += 4000;
                        break;
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD.TEST.SlaWeekHasNoData( _timeout, "widget-00000000000000000000000000000227" ) );
                        break;
                    case 9:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202], false, "00227-2" ) );
                        break;
                    case 10:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                        _timeout += 4000;
                        break;
                    case 12:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD.ACTION.removeDowntimes( _timeout ) );
                        _timeout += 10000;
                        break;
                    case 13:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD.TEST.SlaWeekHasData( _timeout, "widget-00000000000000000000000000000227", 7 ) );
                        break;
                    default:
                        break;
                }
                break;
            default:
                ____( SHINKEN.TOOLS.TEST_AUTO_COMMON_USER_INTERFACE_RUN.do( _timeout ) );
                break;
        }
        return _timeout;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD_RUN || {} );

==> shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05.tar.gz: shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/ui-visualisation/ui_hive/ui_dashboard/shinken-auto-test-run.js <==
SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD_RUN = (function ( self ) {
    var _timeout = 0;
    var _current_window;
    var _current_property;
    var _to_test;
    
    function ____ ( fct ) {
        _timeout += fct;
        return _timeout;
    }
    
    self.do = function () {
        switch ( __shinken_test_type ) {
            case "00227":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout, "/etc/shinken/modules/sla.cfg", "downtime_period", "exclude" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout, "/etc/shinken/modules/sla.cfg", "unknown_period", "exclude" ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.deleteElement( _timeout, OBJECT.ShinkenElementFactory( {
                            "_id"      : '00000000000000000000000000000227',
                            "host_name": '00227_test_auto_host',
                            "type"     : OBJECT.CONST.ELEMENT.TYPE.HOSTS
                        } ) ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                        _timeout += 10000;
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SLA.ACTION.removeTodaySLAFromUUID( _timeout, "00000000000000000000000000000227" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202], false, "00227-1" ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                        _timeout += 4000;
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( _timeout, "shinken", "hive", "hive-0000000000000000000000000227", {
                            "_id"    : "hive-0000000000000000000000000227", "name": "TEST_AUTO 00227 Hive", "owner": { "uuid": "35000000000000000000000000000000" }, "saveVersion": 1, "tiles": [
                                {
                                    "position": { "x": 0, "y": 0 }, "screen": { "uuid": "dash-00000000000000000000000000000227" }
                                }
                            ], "type": "hive", "uuid": "hive-0000000000000000000000000227", "version": "V02.05.01-RC002"
                        } ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( _timeout, "shinken", "dashboard", "dash-00000000000000000000000000000227", {
                            "_id"        : "dash-00000000000000000000000000000227", "context": "NOTHING", "groupId": 0, "has_unknown_element": false, "name": "TEST_AUTO 00227 Dashboard", "parentScreenUuid": "hive-0000000000000000000000000227",
                            "saveVersion": 1, "status": 3,
                            "uuid"       : "dash-00000000000000000000000000000227", "version": "V02.05.01-RC002", "widgets": [
                                {
                                    "display_name": "SLA", "display_sla_full": true,
                                    "element"     : { "host_name": "00227_test_auto_host", "is_unknown": false, "sla": { "growing": "arrow-stagnant-critical", "week_percentage": 0 }, "uuid": "00000000000000000000000000000227" }, "favorite": false,
                                    "height"      : 3, "inCalculation": false, "name": "sla", "position": { "x": 0, "y": 0 }, "uuid": "widget-00000000000000000000000000000227", "width": 4
                                }
                            ]
                        } ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SERVER_SERVICE.ACTION.upsertDocumentToMongo( _timeout, "shinken", "share", "share-0000000000000000000000000227", {
                            "_id"  : "share-0000000000000000000000000227", "index": 1, "kind": 1, "uuid": "share-0000000000000000000000000227", "screen": { "type": "hive", "uuid": "hive-0000000000000000000000000227" }, "created_on": 1649855720,
                            "owner": { "uuid": "35000000000000000000000000000000", "name": "test_auto_user_executor" }, "screenIsReference": false, "type": "personal", "last_modified_on": 1649855720, "name": "TEST_AUTO 00227 Share"
                        } ) );
                        _timeout += 4000;
                        break;
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_WIDGET_SLA.TEST.dataDetailForWeek( _timeout, "widget-00000000000000000000000000000227", [null, null, null, null, null, null, null] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_WIDGET_SLA.TEST.hasIconNoDataForWeek( _timeout, "widget-00000000000000000000000000000227" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_WIDGET_SLA.TEST.hasIconNoDataForToday( _timeout, "widget-00000000000000000000000000000227" ) );
                        break;
                    case 9:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202], false, "00227-2" ) );
                        break;
                    case 10:
                        ____( SHINKEN.TOOLS.TEST_AUTO_APPLY.ACTION.clickOnExecuteApply( _timeout ) );
                        _timeout += 4000;
                        break;
                    case 12:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD.ACTION.removeDowntimes( _timeout ) );
                        _timeout += 10000;
                        break;
                    case 13:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_WIDGET_SLA.TEST.dataDetailForWeek( _timeout, "widget-00000000000000000000000000000227", [null, null, null, null, null, null, 100] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_WIDGET_SLA.TEST.hasIconNoDataForWeek( _timeout, "widget-00000000000000000000000000000227", true ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_WIDGET_SLA.TEST.hasIconNoDataForToday( _timeout, "widget-00000000000000000000000000000227", true ) );
                        break;
                }
                break;
            default:
                ____( SHINKEN.TOOLS.TEST_AUTO_COMMON_USER_INTERFACE_RUN.do( _timeout ) );
                break;
        }
        return _timeout;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_DASHBOARD_RUN || {} );
